@@ -3,7 +3,7 @@ package Bit::Manip;
 use warnings;
 use strict;
 
-our $VERSION = '0.02';
+our $VERSION = '1.00';
 
 require XSLoader;
 XSLoader::load('Bit::Manip', $VERSION);
@@ -51,8 +51,8 @@ sub bit_get {
     _bit_get($data, $msb, $lsb);
 }
 sub bit_set {
-    my ($data, $lsb, $value) = @_;
-    return _bit_set($data, $lsb, $value);
+    my ($data, $lsb, $bits, $value) = @_;
+    return _bit_set($data, $lsb, $bits, $value);
 }
 sub bit_toggle {
     my ($data, $bit) = @_;
@@ -118,7 +118,7 @@ Currently, up to 32-bit integers are supported.
 
 =head1 EXPORT_OK
 
-Use the C<:all> tag (eg: use Bit::Manip qw(:all);) to import the following
+Use the C<:all> tag (eg: C<use Bit::Manip qw(:all);>) to import the following
 functions into your namespace, or pick and choose individually:
 
     bit_bin
